#!/bin/sh
#
# Check for new CD versions of Sophos and update as available.
#
# Paths to your binaries may be different if you are not running a
# Mandrake distribution.
#
VIRUS_EMAIL=virusalert
SYSADMIN_EMAIL=,leonb
TOPDIR=/usr/local
#
export PATH=/home/sweep/bin:$PATH
cd $OPTDIR/tmp
SOPHOS_VERSION=$(
  $TOPDIR/bin/sweep -v |
  /bin/gawk '/^Product version / { print gensub("\\.","","",$4) }'
)
#
# if your CD is not automounted, have a shot at mounting it here
#
MANUAL_MOUNT=no
if ! ( mount | grep -q '/mnt/cdrom' ); then
	MANUAL_MOUNT=yes
	mount /dev/cdrom /mnt/cdrom &> /dev/null
fi
#
# One day we might get cerfystikatud and check to see if it is auto
# mounted and if not (and it is mounted) unmount it first in case
# you are misfortunate enough to have a badly behaved CD drive.
#
if ! [ -d /mnt/cdrom/unix -a -d /mnt/cdrom/DISKIMGS -a -d /mnt/cdrom/TOOLS ]; then
	/usr/bin/logger -t sophos "No Sophos CD in drive ($SOPHOS_VERSION)"
	if [ $MANUAL_MOUNT = yes ]; then
		umount /mnt/cdrom
	fi
	/usr/bin/eject
	exit 1
fi
if ! [ -f /mnt/cdrom/unix/linux.intel.libc6.tar ]; then
	/usr/bin/logger -t sophos "Sophos Linux update missing from CD ($SOPHOS_VERSION)"
	echo "Could not retrieve Linux update from CD, still running $SOPHOS_VERSION. Please remove Sophos CD and close drive." | \
	  /bin/mail -s "Sophos software update failure" \
	  $VIRUS_EMAIL$ADMIN_EMAIL &> /dev/null
	if [ $MANUAL_MOUNT = yes ]; then
		umount /mnt/cdrom
	fi
	/usr/bin/eject
	exit 2
fi
rm -rf sav-install
/bin/tar xf /mnt/cdrom/unix/linux.intel.libc6.tar
CD_VERSION=$(/bin/ls sav-install/vdl-*.dat | \
  /bin/gawk -F[.-] '/^sav-install.vdl-/ { print $3 $4 }')
if [ "$CD_VERSION" -le "300" ]; then
	/usr/bin/logger -t sophos "Unable to retrieve a valid Sophos update from CD ($SOPHOS_VERSION)"
	echo "Could not retrieve CD version of Sweep, still running $SOPHOS_VERSION. Please remove Sophos CD and close drive." | \
	  /bin/mail -s "Sophos software update failure" \
	  $VIRUS_EMAIL$ADMIN_EMAIL &> /dev/null
	if [ $MANUAL_MOUNT = yes ]; then
		umount /mnt/cdrom
	fi
	/usr/bin/eject
	exit 3
fi
if [ "$CD_VERSION" -eq "$SOPHOS_VERSION" ]; then
	/usr/bin/logger -t sophos CD version of Sophos is not new
	echo "Sophos CD is same as running version ($SOPHOS_VERSION). Please remove the CD and close the drive." | \
	  /bin/mail -s "Sophos update CD processed" virusalert
	if [ $MANUAL_MOUNT = yes ]; then
		umount /mnt/cdrom
	fi
	/usr/bin/eject
	exit 0
fi
if [ "$CD_VERSION" -gt "$SOPHOS_VERSION" ]; then
	/usr/bin/logger -t sophos Updating Sweep from version $SOPHOS_VERSION to $CD_VERSION
	cd sav-install
	./install.sh -d $TOPDIR -m /usr/share/man/man1
	rm -rf $TOPDIR/sav/*.ide $TOPDIR/tmp/sav-install
	NEW_VERSION=$(
	  $TOPDIR/bin/sweep -v |
	  /bin/gawk '/^Product version / { print gensub("\\.","","",$4) }'
	)
	echo "Now running Sweep $NEW_VERSION, old version was $SOPHOS_VERSION, CD claims $CD_VERSION. Please remove Sophos CD and close drive." | \
	  /bin/mail -s "Updated Sophos software" \
	  $VIRUS_EMAIL$ADMIN_EMAIL &> /dev/null
	/usr/bin/logger -t sophos "Update complete - $NEW_VERSION from $SOPHOS_VERSION ($CD_VERSION)"
	/usr/bin/eject
	exit 0
fi
/usr/bin/logger -t sophos CD version of Sophos is OLDER than running version
echo "CD version of Sweep ($CD_VERSION) is OLDER than running version ($SOPHOS_VERSION). Please remove Sophos CD and close drive." | \
  /bin/mail -s "Sophos software update failure" \
  $VIRUS_EMAIL$ADMIN_EMAIL &> /dev/null
if [ $MANUAL_MOUNT = yes ]; then
	umount /mnt/cdrom
fi
/usr/bin/eject
exit 2
